RCN_EVENTS_ENABLE = "rcn.events.enable"
RCN_EVENTS_WAITTIME = "rcn.events.waittime"
RCN_EVENTS_INVOKER_SLEEP_TIME = "rcn.events.expected.invoker.time"

RCN_FLASK_APP_ENABLED = "app.flask.enabled"
RCN_FLASK_APP_NAME = "app.flask.name"
RCN_FLASK_APP_PORT = "app.flask.port"
RCN_FLASK_APP_LISTEN = "app.flask.listen"
RCN_FLASK_APP_CONTEXT_URL = "app.flask.contextUrl"
RCN_FLASK_APP_CONFIGS_LIST = "app.flask.configs"
RCN_FLASK_APP_BACKEND_SERVER = "app.flask.backend"